@@ -53,9 +53,9 @@ public:
 
     ~SambaAccessLogMode();
 
-    Analyzer *createAnalyzer(const QVariant &options = QVariant());
+    Analyzer *createAnalyzer(const QVariant &options = QVariant()) Q_DECL_OVERRIDE;
 
-    QList<LogFile> createLogFiles();
+    QList<LogFile> createLogFiles() Q_DECL_OVERRIDE;
 };
 
 #endif // _SAMBA_ACCESS_LOG_MODE_H_
